summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/view.h
diff options
context:
space:
mode:
authorharanp <haranp@c06c8d41-db1a-0410-9941-cceddc491573>2009-02-17 10:26:02 +0000
committerharanp <haranp@c06c8d41-db1a-0410-9941-cceddc491573>2009-02-17 10:26:02 +0000
commita298a872647d9beb0d30d71472a0e08e83df1440 (patch)
treed2716e55876a3681c3a78aa7930576c1cd54d8d2 /crawl-ref/source/view.h
parent77e8bbcc1dd439c368a9deb653daed4a6fe82851 (diff)
downloadcrawl-ref-a298a872647d9beb0d30d71472a0e08e83df1440.tar.gz
crawl-ref-a298a872647d9beb0d30d71472a0e08e83df1440.zip
Change elemental type colour enum to use ETC_ prefix instead of EC_
prefix, which was conflicting with the Abyssal entry cause enum. Fixes [2605869]. git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@9110 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref/source/view.h')
-rw-r--r--crawl-ref/source/view.h80
1 files changed, 40 insertions, 40 deletions
diff --git a/crawl-ref/source/view.h b/crawl-ref/source/view.h
index ed18a4536c..4f6f78d4f5 100644
--- a/crawl-ref/source/view.h
+++ b/crawl-ref/source/view.h
@@ -18,45 +18,45 @@
// initfile.cc (str_to_colour)!
enum element_type
{
- EC_FIRE = 32, // fiery colours (must be first and > highest colour)
- EC_ICE, // icy colours
- EC_EARTH, // earthy colours
- EC_ELECTRICITY, // electrical side of air
- EC_AIR, // non-electric and general air magic
- EC_POISON, // used only for venom mage and stalker stuff
- EC_WATER, // used only for the elemental
- EC_MAGIC, // general magical effect
- EC_MUTAGENIC, // transmute, poly, radiation effects
- EC_WARP, // teleportation and anything similar
- EC_ENCHANT, // magical enhancements
- EC_HEAL, // holy healing (not necromantic stuff)
- EC_HOLY, // general "good" god effects
- EC_DARK, // darkness
- EC_DEATH, // currently only assassin (and equal to EC_NECRO)
- EC_NECRO, // necromancy stuff
- EC_UNHOLY, // demonology stuff
- EC_VEHUMET, // vehumet's odd-ball colours
- EC_BEOGH, // Beogh altar colours
- EC_CRYSTAL, // colours of crystal
- EC_BLOOD, // colours of blood
- EC_SMOKE, // colours of smoke
- EC_SLIME, // colours of slime
- EC_JEWEL, // colourful
- EC_ELVEN, // used for colouring elf fabric items
- EC_DWARVEN, // used for colouring dwarf fabric items
- EC_ORCISH, // used for colouring orc fabric items
- EC_GILA, // gila monster colours
- EC_FLOOR, // colour of the area's floor
- EC_ROCK, // colour of the area's rock
- EC_STONE, // colour of the area's stone
- EC_MIST, // colour of mist
- EC_SHIMMER_BLUE, // shimmering colours of blue.
- EC_DECAY, // colour of decay/swamp
- EC_SILVER, // colour of silver
- EC_GOLD, // colour of gold
- EC_IRON, // colour of iron
- EC_BONE, // colour of bone
- EC_RANDOM // any colour (except BLACK)
+ ETC_FIRE = 32, // fiery colours (must be first and > highest colour)
+ ETC_ICE, // icy colours
+ ETC_EARTH, // earthy colours
+ ETC_ELECTRICITY, // electrical side of air
+ ETC_AIR, // non-electric and general air magic
+ ETC_POISON, // used only for venom mage and stalker stuff
+ ETC_WATER, // used only for the elemental
+ ETC_MAGIC, // general magical effect
+ ETC_MUTAGENIC, // transmute, poly, radiation effects
+ ETC_WARP, // teleportation and anything similar
+ ETC_ENCHANT, // magical enhancements
+ ETC_HEAL, // holy healing (not necromantic stuff)
+ ETC_HOLY, // general "good" god effects
+ ETC_DARK, // darkness
+ ETC_DEATH, // currently only assassin (and equal to ETC_NECRO)
+ ETC_NECRO, // necromancy stuff
+ ETC_UNHOLY, // demonology stuff
+ ETC_VEHUMET, // vehumet's oddball colours
+ ETC_BEOGH, // Beogh altar colours
+ ETC_CRYSTAL, // colours of crystal
+ ETC_BLOOD, // colours of blood
+ ETC_SMOKE, // colours of smoke
+ ETC_SLIME, // colours of slime
+ ETC_JEWEL, // colourful
+ ETC_ELVEN, // used for colouring elf fabric items
+ ETC_DWARVEN, // used for colouring dwarf fabric items
+ ETC_ORCISH, // used for colouring orc fabric items
+ ETC_GILA, // gila monster colours
+ ETC_FLOOR, // colour of the area's floor
+ ETC_ROCK, // colour of the area's rock
+ ETC_STONE, // colour of the area's stone
+ ETC_MIST, // colour of mist
+ ETC_SHIMMER_BLUE, // shimmering colours of blue.
+ ETC_DECAY, // colour of decay/swamp
+ ETC_SILVER, // colour of silver
+ ETC_GOLD, // colour of gold
+ ETC_IRON, // colour of iron
+ ETC_BONE, // colour of bone
+ ETC_RANDOM // any colour (except BLACK)
};
void init_char_table(char_set_type set);
@@ -101,7 +101,7 @@ int multibyte_strlen(const std::string &s);
void get_item_symbol(unsigned int object, unsigned *ch,
unsigned short *colour);
// Applies EC_ colour substitutions and brands.
unsigned real_colour(unsigned raw_colour);
int get_mons_colour(const monsters *mons);
@@ -101,7 +101,7 @@ int multibyte_strlen(const std::string &s);
void get_item_symbol(unsigned int object, unsigned *ch,
unsigned short *colour);
-// Applies EC_ colour substitutions and brands.
+// Applies ETC_ colour substitutions and brands.
unsigned real_colour(unsigned raw_colour);
int get_mons_colour(const monsters *mons);